==> dnacentersdk-2.10.0.tar.gz: dnacentersdk-2.10.0/dnacentersdk/models/validators/v2_3_7_9/jsd_cc1599012a5a59c8abdda5376b5cc583.py <==
# -*- coding: utf-8 -*-
"""Cisco DNA Center UpdateTransitNetworks data model.

Copyright (c) 2025 Cisco Systems.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""

from __future__ import absolute_import, division, print_function, unicode_literals

import json
from builtins import *

import fastjsonschema

from dnacentersdk.exceptions import MalformedRequest


class JSONSchemaValidatorCc1599012A5A59C8AbddA5376B5Cc583(object):
    """UpdateTransitNetworks request schema definition."""
    def __init__(self):
        super(JSONSchemaValidatorCc1599012A5A59C8AbddA5376B5Cc583, self).__init__()
        self._validator = fastjsonschema.compile(json.loads(
            '''{
                "$schema": "http://json-schema.org/draft-04/schema#",
                "items": {
                "properties": {
                "id": {
                "type": "string"
                },
                "ipTransitSettings": {
                "properties": {
                "autonomousSystemNumber": {
                "type": "string"
                },
                "routingProtocolName": {
                "enum": [
                "BGP"
                ],
                "type": "string"
                }
                },
                "type": "object"
                },
                "name": {
                "type": "string"
                },
                "sdaTransitSettings": {
                "properties": {
                "controlPlaneNetworkDeviceIds": {
                "items": {
                "type": "string"
                },
                "type": "array"
                },
                "isMulticastOverTransitEnabled": {
                "type": "boolean"
                }
                },
                "type": "object"
                },
                "siteId": {
                "type": "string"
                },
                "type": {
                "enum": [
                "IP_BASED_TRANSIT",
                "SDA_LISP_PUB_SUB_TRANSIT",
                "SDA_LISP_BGP_TRANSIT"
                ],
                "type": "string"
                }
                },
                "type": "object"
                },
                "type": "array"
                }'''.replace("\n" + ' ' * 16, '')
        ))

    def validate(self, request):
        try:
            self._validator(request)
        except fastjsonschema.exceptions.JsonSchemaException as e:
            raise MalformedRequest(
                '{} is invalid. Reason: {}'.format(request, e.message)
            )

==> dnacentersdk-2.10.1.tar.gz: dnacentersdk-2.10.1/dnacentersdk/models/validators/v2_3_7_6/jsd_cc1599012a5a59c8abdda5376b5cc583.py <==
# -*- coding: utf-8 -*-
"""Cisco DNA Center UpdateTransitNetworksV1 data model.

Copyright (c) 2024 Cisco Systems.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""


import json
from builtins import *

import fastjsonschema

from dnacentersdk.exceptions import MalformedRequest


class JSONSchemaValidatorCc1599012A5A59C8AbddA5376B5Cc583(object):
    """UpdateTransitNetworksV1 request schema definition."""

    def __init__(self):
        super(JSONSchemaValidatorCc1599012A5A59C8AbddA5376B5Cc583, self).__init__()
        self._validator = fastjsonschema.compile(
            json.loads(
                """{
                "$schema": "http://json-schema.org/draft-04/schema#",
                "items": {
                "properties": {
                "id": {
                "type": "string"
                },
                "ipTransitSettings": {
                "properties": {
                "autonomousSystemNumber": {
                "type": "string"
                },
                "routingProtocolName": {
                "enum": [
                "BGP"
                ],
                "type": "string"
                }
                },
                "type": "object"
                },
                "name": {
                "type": "string"
                },
                "sdaTransitSettings": {
                "properties": {
                "controlPlaneNetworkDeviceIds": {
                "items": {
                "type": "string"
                },
                "type": "array"
                },
                "isMulticastOverTransitEnabled": {
                "type": "boolean"
                }
                },
                "type": "object"
                },
                "type": {
                "enum": [
                "IP_BASED_TRANSIT",
                "SDA_LISP_PUB_SUB_TRANSIT",
                "SDA_LISP_BGP_TRANSIT"
                ],
                "type": "string"
                }
                },
                "type": "object"
                },
                "type": "array"
                }""".replace(
                    "\n" + " " * 16, ""
                )
            )
        )

    def validate(self, request):
        try:
            self._validator(request)
        except fastjsonschema.exceptions.JsonSchemaException as e:
            raise MalformedRequest(
                "{} is invalid. Reason: {}".format(request, e.message)
            )
